@@ -7,7 +7,7 @@ use strict;
 use warnings;
 
 use parent 'Graph::Writer';
-our $VERSION = '2.03';
+our $VERSION = '2.04';
 
 #-----------------------------------------------------------------------
 # List of valid daVinci attributes for the entire graph, per node,
@@ -136,7 +136,7 @@ sub _dump_node
 
         $doneref->{$node} = 1;
 
-        @children = $graph->successors($node);
+        @children = sort $graph->successors($node);
         if (@children == 0)
         {
             print $FILE ", []";
